@@ -1,6 +1,7 @@
 #include <QVBoxLayout>
 #include <QStackedWidget>
 #include <QFrame>
+#include <QTimer>
 
 #include "mainwindow.h"
 #include "netinterfaces.h"
@@ -48,11 +49,19 @@ MainWindow::MainWindow(QObject *parent)
 	setWindowTitle(tr("Mad Developer"));
 }
 
+void
+MainWindow::activateLauncher(void)
+{
+	m_netinterfaces->setEditButtonEnabled(true);
+	m_launcher->activateButtons(true);
+}
+
 void
 MainWindow::showLauncher(void)
 {
+	m_launcher->activateButtons(false);
 	m_stack->setCurrentIndex(LAUNCHER);
-	m_netinterfaces->setEditButtonEnabled(true);
+	QTimer::singleShot(250, this, SLOT(activateLauncher()));
 }
 
 void
@@ -66,11 +75,13 @@ MainWindow::showPasswd(void)
 void
 MainWindow::showEdit(void)
 {
+	m_netinterfaces->setEditButtonEnabled(false);
 	m_stack->setCurrentIndex(EDIT);
 }
 
 void
 MainWindow::showUsbManage(void)
 {
+	m_netinterfaces->setEditButtonEnabled(false);
 	m_stack->setCurrentIndex(USB);
 }
